==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TemplateHeaderCellInfoDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TemplateHeaderCellInfoDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateHeaderCellInfoDescription, _super);
    function TemplateHeaderCellInfoDescription() {
        var _this = _super.call(this) || this;
        _this.fo = false;
        return _this;
    }
    TemplateHeaderCellInfoDescription.prototype.get_type = function () {
        return "TemplateHeaderCellInfo";
    };
    Object.defineProperty(TemplateHeaderCellInfoDescription.prototype, "isFilterUIVisible", {
        get: function () {
            return this.fo;
        },
        set: function (a) {
            this.fo = a;
            this.e("IsFilterUIVisible");
        },
        enumerable: true,
        configurable: true
    });
    TemplateHeaderCellInfoDescription.$t = markType(TemplateHeaderCellInfoDescription, 'TemplateHeaderCellInfoDescription', TemplateCellInfoDescription.$);
    TemplateHeaderCellInfoDescription.__marshalByValue2 = true;
    TemplateHeaderCellInfoDescription.__marshalByValueAlias2 = "TemplateHeaderCellModel";
    return TemplateHeaderCellInfoDescription;
}(TemplateCellInfoDescription));
export { TemplateHeaderCellInfoDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/TemplateHeaderCellInfoDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TemplateCellInfoDescription } from "./TemplateCellInfoDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TemplateHeaderCellInfoDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateHeaderCellInfoDescription, _super);
    function TemplateHeaderCellInfoDescription() {
        var _this = _super.call(this) || this;
        _this.fq = false;
        return _this;
    }
    TemplateHeaderCellInfoDescription.prototype.get_type = function () {
        return "TemplateHeaderCellInfo";
    };
    Object.defineProperty(TemplateHeaderCellInfoDescription.prototype, "isFilterUIVisible", {
        get: function () {
            return this.fq;
        },
        set: function (a) {
            this.fq = a;
            this.g("IsFilterUIVisible");
        },
        enumerable: false,
        configurable: true
    });
    TemplateHeaderCellInfoDescription.$t = markType(TemplateHeaderCellInfoDescription, 'TemplateHeaderCellInfoDescription', TemplateCellInfoDescription.$);
    TemplateHeaderCellInfoDescription.__marshalByValue2 = true;
    TemplateHeaderCellInfoDescription.__marshalByValueAlias2 = "TemplateHeaderCellModel";
    return TemplateHeaderCellInfoDescription;
}(TemplateCellInfoDescription));
export { TemplateHeaderCellInfoDescription };
